# cats-igate

Reference CATS/FELINET I-gate/digipeater for the Raspberry Pi. Requires an I-Gate board: https://gitlab.scd31.com/cats/pi-hardware

## Installing (Prebuilt Packages)

Download the .deb file for your Pi:

[Pi Zero/1](https://gitlab.scd31.com/cats/igate/builds/artifacts/master/browse/target/arm-unknown-linux-musleabihf/debian?job=build_pi_old)

[Pi 2/3/4/5](https://gitlab.scd31.com/cats/igate/builds/artifacts/master/browse/target/aarch64-unknown-linux-gnu/debian/?job=build_pi_modern)

Once downloaded, the package can be installed with `sudo dpkg -i FILENAME.deb`, where `FILENAME.deb` is the file you downloaded.

## Configuring

First of all, the SPI bus must be enabled on the Pi. It's disabled by default and is required to communicate with the hardware. This can be enabled in the `raspi-config` utility under "Interface Options". After enabling, restart the Pi.

The configuration for the I-gate lives in `/etc/cats_igate/config.toml`. Make sure to update this before using the utility - most importantly, the callsign must be configured.

## Usage

For debugging, a single command line option exists. Running `cats-igate -x <freq>` in a terminal will send out constant test packets (properly identified, of course) which is useful for diagnostics. Please don't run this on the main CATS frequency or it will utilize 100% of the channel! Also, make sure whichever frequency you choose is unused.

The I-gate ships with a service file, which allows it to run autonomously. To start the service, run `sudo systemctl start cats-igate`. To have the service automatically start at bootup, run `sudo systemctl enable cats-igate`.


## Building From Source

You probably don't need to do this unless you're planning to change the code, or if you're having problems with the prebuilt binaries.

To build the software, you will need to install [Rustup](https://rustup.rs/). You'll also need to install some dependencies:

```bash
sudo apt install git protobuf-compiler
cargo install cargo-deb
rustup target add aarch64-unknown-linux-gnu # necessary to build for all RPi models 2B and newer
rustup target add arm-unknown-linux-musleabihf # necessary to build for RPi zero, and RPi 1
```

After these are installed, restart your terminal, or open a new one. Then run these commands:

```bash
git clone https://gitlab.scd31.com/cats/igate
cd igate
git pull
```

To build for modern Raspberry Pis (everything newer than Model 2B):
```bash
cargo deb --target aarch64-unknown-linux-gnu
```

To build for the Rasberry Pi Zero or Pi 1:
```bash
cargo deb --target arm-unknown-linux-musleabihf
```

The resulting deb package will placed in `target/$TARGET_ARCH/debian/cats-igate_VERSION_arm64.deb`. The package can be installed with `sudo dpkg -i target/$TARGET_ARCH/debian/cats-igate_VERSION.deb`, replacing `TARGET_ARCH` with the architecture specified in `cargo deb`, and `VERSION` with whatever version and architecture was built.
